@@ -1,5 +1,4 @@
 plotSpatial <- function(data, param, roi.data.path, image.path, probs=c(0.01, 0.99), ...) {
-	img <- readJPEG(image.path)
 	roi.data <- NULL
 	load(roi.data.path)
 	if (is.data.frame(data)) {
@@ -8,11 +7,10 @@ plotSpatial <- function(data, param, roi.data.path, image.path, probs=c(0.01, 0.
 		the.data <- data[,param]
 		quantiles <- quantile(the.data, probs, na.rm=TRUE)
 		the.data[the.data<quantiles[1]] <- NA
-		the.data[the.data>quantiles[2]] <- NA	
-		phase.array <- array(dim=c(nrow(r), ncol(r),1))
-		phase.array[,,1][roi.data[[1]]$pixels.in.roi$pip==1] <- the.data
-		phase <- brick(phase.array, xmn=0, xmx=ncol(r), 
-			ymn=0, ymx=nrow(r))
+		the.data[the.data>quantiles[2]] <- NA
+		phase <- roi.data[[1]]$mask
+		raster::values(phase)[values(roi.data[[1]]$mask) == 0] <- NA
+		raster::values(phase)[values(roi.data[[1]]$mask) ==1] <- the.data	
 		suppressWarnings(plot(phase, add=TRUE, ...))
 	} else {
 	## match data and roi names
@@ -26,16 +24,15 @@ plotSpatial <- function(data, param, roi.data.path, image.path, probs=c(0.01, 0.
 		}
 		r <- brick(image.path)
 		plotRGB(r)
-		phase.array <- array(dim=c(nrow(r), ncol(r),1))
+		phase <- roi.data[[1]]$mask
+		raster::values(phase) <- NA
 		for (a in 1:roi.num) {
 		the.data <- x[[a]]
 		quantiles <- quantile(the.data, probs, na.rm=TRUE)
 		the.data[the.data<quantiles[1]] <- NA
 		the.data[the.data>quantiles[2]] <- NA
-		phase.array[,,1][roi.data.ordered[[a]]$pixels.in.roi$pip==1] <- the.data
+		raster::values(phase)[values(roi.data[[a]]$mask) ==1] <- the.data	
 		}
-		phase <- brick(phase.array, xmn=0, xmx=ncol(r), 
-			ymn=0, ymx=nrow(r))
 		suppressWarnings(plot(phase, add=TRUE, ...))
 	}
 }
